MacroExt extension

on

Static Methods

decodeDateTime(Object? value) DateTime

Available on Enum, provided by the MacroExt extension

decodeEnum<K extends Enum, V>(List<K> enumValues, Object? source, {K? unknownValue}) → K

Available on Enum, provided by the MacroExt extension

Returns the key associated with value source from enumValues, if one exists.
decodeNullableDateTime(Object? value) DateTime?

Available on Enum, provided by the MacroExt extension

decodeNullableEnum<K extends Enum, V>(List<K> enumValues, Object? source, {Enum? unknownValue}) → K?

Available on Enum, provided by the MacroExt extension

Returns the key associated with value source from enumValues, if one exists.
decodeNullableGeneric<T>(Object? input, T? fromJson(Object? value)) → T?

Available on Enum, provided by the MacroExt extension

encodeNullableGeneric<T>(T? input, Object? toJson(T value)) Object?

Available on Enum, provided by the MacroExt extension