ShaderBundleManifest class
A parsed *.shaderbundle.json manifest with its shader source paths
already resolved to absolute paths.
Constructors
Properties
-
entries
→ Map<
String, dynamic> -
Decoded manifest with
filevalues resolved to absolute pathsfinal - hashCode → int
-
The hash code for this object.
no setterinherited
- outputFileName → String
-
Output file name, e.g.
flutter_example.shaderbundlefinal - relativeDir → String
-
Directory of the manifest relative to the watched shader directory
(empty string when the manifest sits at its root).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourcePath → String
-
Absolute path of the manifest json file
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited